@@ -1,6 +1,7 @@
 package main
 
 import (
+	"crypto/tls"
 	"flag"
 	"fmt"
 	"net/http"
@@ -18,6 +19,7 @@ import (
 
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/api/client"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/controller/operators/catalog"
+	"github.com/operator-framework/operator-lifecycle-manager/pkg/lib/filemonitor"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/lib/signals"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/metrics"
 	olmversion "github.com/operator-framework/operator-lifecycle-manager/pkg/version"
@@ -116,8 +118,20 @@ func main() {
 	metricsMux := http.NewServeMux()
 	metricsMux.Handle("/metrics", promhttp.Handler())
 	if useTLS {
+		tlsGetCertFn, err := filemonitor.OLMGetCertRotationFn(logger, *tlsCertPath, *tlsKeyPath)
+		if err != nil {
+			logger.Errorf("Certificate monitoring for metrics (https) failed: %v", err)
+		}
+
 		go func() {
-			err := http.ListenAndServeTLS(":8081", *tlsCertPath, *tlsKeyPath, metricsMux)
+			httpsServer := &http.Server{
+				Addr:    ":8081",
+				Handler: metricsMux,
+				TLSConfig: &tls.Config{
+					GetCertificate: tlsGetCertFn,
+				},
+			}
+			err := httpsServer.ListenAndServeTLS("", "")
 			if err != nil {
 				logger.Errorf("Metrics (https) serving failed: %v", err)
 			}
